        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 12 <strong>control</strong><br>0,2,8,9,12,18,22,25,36,42,43,47';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 11 <br>5,14,15,20,29,32,33,39,40,44,46';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>13</strong> miembros: 11 <br>1,3,11,13,23,27,28,30,31,37,49';}
       if(rr==7 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>7</strong> miembros: 7 <br>7,10,17,24,26,35,50';}
       if(rr==7 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>5</strong> representante: <strong>48</strong> miembros: 6 <br>4,6,16,34,38,48';}
       if(rr==7 && cc==6){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 4 <br>19,21,41,45';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 12 <strong>control</strong><br>0,2,8,9,12,18,22,25,36,42,43,47';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 11 <br>5,14,15,20,29,32,33,39,40,44,46';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>13</strong> miembros: 11 <br>1,3,11,13,23,27,28,30,31,37,49';}
       if(rr==34 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>7</strong> miembros: 7 <br>7,10,17,24,26,35,50';}
       if(rr==34 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>5</strong> representante: <strong>48</strong> miembros: 6 <br>4,6,16,34,38,48';}
       if(rr==34 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 4 <br>19,21,41,45';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 12 <strong>control</strong><br>0,2,8,9,12,18,22,25,36,42,43,47';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 11 <br>5,14,15,20,29,32,33,39,40,44,46';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>13</strong> miembros: 11 <br>1,3,11,13,23,27,28,30,31,37,49';}
       if(rr==35 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>7</strong> miembros: 7 <br>7,10,17,24,26,35,50';}
       if(rr==35 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>5</strong> representante: <strong>48</strong> miembros: 6 <br>4,6,16,34,38,48';}
       if(rr==35 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 4 <br>19,21,41,45';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 12 <strong>control</strong><br>0,2,8,9,12,18,22,25,36,42,43,47';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 11 <br>5,14,15,20,29,32,33,39,40,44,46';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>13</strong> miembros: 11 <br>1,3,11,13,23,27,28,30,31,37,49';}
       if(rr==36 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>7</strong> miembros: 7 <br>7,10,17,24,26,35,50';}
       if(rr==36 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>5</strong> representante: <strong>48</strong> miembros: 6 <br>4,6,16,34,38,48';}
       if(rr==36 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 4 <br>19,21,41,45';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 12 <strong>control</strong><br>0,2,8,9,12,18,22,25,36,42,43,47';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 11 <br>5,14,15,20,29,32,33,39,40,44,46';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>13</strong> miembros: 11 <br>1,3,11,13,23,27,28,30,31,37,49';}
       if(rr==37 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>7</strong> miembros: 7 <br>7,10,17,24,26,35,50';}
       if(rr==37 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>5</strong> representante: <strong>48</strong> miembros: 6 <br>4,6,16,34,38,48';}
       if(rr==37 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 4 <br>19,21,41,45';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 12 <strong>control</strong><br>0,2,8,9,12,18,22,25,36,42,43,47';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 11 <br>5,14,15,20,29,32,33,39,40,44,46';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>13</strong> miembros: 11 <br>1,3,11,13,23,27,28,30,31,37,49';}
       if(rr==38 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>7</strong> miembros: 7 <br>7,10,17,24,26,35,50';}
       if(rr==38 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>5</strong> representante: <strong>48</strong> miembros: 6 <br>4,6,16,34,38,48';}
       if(rr==38 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 4 <br>19,21,41,45';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>18</strong> miembros: 12 <strong>control</strong><br>0,2,8,9,12,18,22,25,36,42,43,47';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 11 <br>5,14,15,20,29,32,33,39,40,44,46';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>13</strong> miembros: 11 <br>1,3,11,13,23,27,28,30,31,37,49';}
       if(rr==39 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>7</strong> miembros: 7 <br>7,10,17,24,26,35,50';}
       if(rr==39 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>5</strong> representante: <strong>48</strong> miembros: 6 <br>4,6,16,34,38,48';}
       if(rr==39 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>6</strong> representante: <strong>19</strong> miembros: 4 <br>19,21,41,45';}
}
